# Epic: [EPIC-XXX] [Title]

**Status:** Draft | In Progress | Done
**Created:** YYYY-MM-DD
**Last Updated:** YYYY-MM-DD
**Last Modified By:** [git user email]

---

## Description

[Epic description - high-level goal or theme]

---

## Features

| Feature ID | Title | Status | Description |
|------------|-------|--------|-------------|
| FEAT-001 | [Feature Title] | Draft | [Brief description] |

---

## Stories

| Story ID | Title | Status | Priority | Feature |
|----------|-------|--------|----------|---------|
| STORY-001 | [Story Title] | Draft | P1 | FEAT-001 |

---

## Success Criteria

- [ ] Criterion 1
- [ ] Criterion 2

---

## History

| Date | Change | By |
|------|--------|-----|
| YYYY-MM-DD | Created | [Name] |
